.. _spkg_sagemath_doc_pdf:

sagemath_doc_pdf: SageMath documentation in PDF format
======================================================

Upon installation, this package builds the SageMath documentation
in PDF format.

It is an optional package.  It can be enabled at configuration time
using ``./configure --enable-sagemath_doc_pdf``.  Alternatively,
it can be installed by using ``make doc-pdf``.


Type
----

optional


Dependencies
------------

- $(PYTHON)
- $(PYTHON_TOOLCHAIN)
- $(SAGERUNTIME)
- :ref:`spkg_conway_polynomials`
- :ref:`spkg_elliptic_curves`
- :ref:`spkg_fpylll`
- :ref:`spkg_free_fonts`
- :ref:`spkg_furo`
- :ref:`spkg_graphs`
- :ref:`spkg_ipykernel`
- :ref:`spkg_ipywidgets`
- :ref:`spkg_jmol`
- :ref:`spkg_jupyter_client`
- :ref:`spkg_jupyter_sphinx`
- :ref:`spkg_mathjax`
- :ref:`spkg_matplotlib`
- :ref:`spkg_maxima`
- :ref:`spkg_meson_python`
- :ref:`spkg_mpmath`
- :ref:`spkg_networkx`
- :ref:`spkg_pillow`
- :ref:`spkg_pplpy_doc`
- :ref:`spkg_sage_docbuild`
- :ref:`spkg_sagelib`
- :ref:`spkg_scipy`
- :ref:`spkg_sphinx`
- :ref:`spkg_sphinx_copybutton`
- :ref:`spkg_sphinx_inline_tabs`
- :ref:`spkg_sympy`
- :ref:`spkg_tachyon`
- :ref:`spkg_texlive`
- :ref:`spkg_texlive_luatex`
- :ref:`spkg_xindy`

Version Information
-------------------

package-version.txt::

    10.8.2.rc1

version_requirements.txt::

    passagemath-doc-pdf == 10.8.2rc1

Installation commands
---------------------

.. tab:: PyPI:

   .. CODE-BLOCK:: bash

       $ pip install passagemath-doc-pdf==10.8.2rc1

.. tab:: Sage distribution:

   .. CODE-BLOCK:: bash

       $ sage -i sagemath_doc_pdf


However, these system packages will not be used for building Sage
because ``spkg-configure.m4`` has not been written for this package;
see :issue:`27330` for more information.
